
Interpreter and reasoner
========================

The interpreter produces Expressions as output. A knowledge base and
automated reasoner are also provided.

.. toctree::
   :titlesonly:

   interp
   expr
   logic
